Class: Gapic::Model::Method::AipLro

Inherits:
Object
  • Object
show all
Includes:
Singleton
Defined in:
lib/gapic/model/method/lro.rb

Overview

AIP-151 LRO Model

Instance Method Summary collapse

Instance Method Details

#aip_lro?Boolean

Returns Whether this is a model for the AIP-151 LRO.

Returns:

  • (Boolean)

    Whether this is a model for the AIP-151 LRO



93
94
95
# File 'lib/gapic/model/method/lro.rb', line 93

def aip_lro?
  true
end

#nonstandard_lro?Boolean

Returns Whether this is a model for the nonstandard LRO.

Returns:

  • (Boolean)

    Whether this is a model for the nonstandard LRO



86
87
88
# File 'lib/gapic/model/method/lro.rb', line 86

def nonstandard_lro?
  false
end