Class: Gapic::Model::Method::NoLro

Inherits:
Object
  • Object
show all
Includes:
Singleton
Defined in:
lib/gapic/model/method/lro.rb

Overview

Method does not represent a long-running operation

Instance Method Summary collapse

Instance Method Details

#aip_lro?Boolean

Returns Whether this is a model for the AIP-151 LRO.

Returns:

  • (Boolean)

    Whether this is a model for the AIP-151 LRO



113
114
115
# File 'lib/gapic/model/method/lro.rb', line 113

def aip_lro?
  false
end

#nonstandard_lro?Boolean

Returns Whether this is a model for the nonstandard LRO.

Returns:

  • (Boolean)

    Whether this is a model for the nonstandard LRO



106
107
108
# File 'lib/gapic/model/method/lro.rb', line 106

def nonstandard_lro?
  false
end