Class: Gapic::Model::Service::NoNonstandardLro

Inherits:
Object
  • Object
show all
Includes:
Singleton
Defined in:
lib/gapic/model/service/nonstandard_lro_provider.rb

Overview

Service does not provide nonstandard LRO polling capabilities

Instance Method Summary collapse

Instance Method Details

#nonstandard_lro?Boolean

Returns Whether this is a model for a nonstandard LRO provider service.

Returns:

  • (Boolean)

    Whether this is a model for a nonstandard LRO provider service



138
139
140
# File 'lib/gapic/model/service/nonstandard_lro_provider.rb', line 138

def nonstandard_lro?
  false
end