Class: Gapic::Presenters::Service::LroClientPresenter

Inherits:
Object
  • Object
show all
Defined in:
lib/gapic/presenters/service/lro_client_presenter.rb

Overview

Presenter for the generation of the client for nonstandard LROs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil) ⇒ LroClientPresenter

Returns a new instance of LroClientPresenter.

Parameters:

  • service (String)

    Full name of the service providing the nonstandard LRO functionality

  • client_class_name (String)

    Full name of the class of the client of the service

  • client_class_docname (String)

    Name of the class as it should appear in the documentation

  • client_var_name (String)

    Name for the variable for the client of the service

  • require_str (String)

    Path to require the client of the service

  • service_description (String)

    The description to place in the comments to this client's attribute in the library services's client class

  • helper_type (String, nil) (defaults to: nil)

    The type of a helper generated for this service if any



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 72

def initialize service:,
               client_class_name:,
               client_class_docname:,
               client_var_name:,
               require_str:,
               service_description:,
               helper_type: nil
  @service = service
  @client_class_name = client_class_name
  @client_class_docname = client_class_docname
  @client_var_name = client_var_name
  @require_str = require_str
  @service_description = service_description
  @helper_type = helper_type
end

Instance Attribute Details

#client_class_docnameString (readonly)

Name of the class as it should appear in the documentation

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#client_class_nameString (readonly)

Full name of the class of the client of the service

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#client_var_nameString (readonly)

Name for the variable for the client of the service

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#helper_typeString. nil (readonly)

The type of a helper generated for this service if any

Returns:

  • (String. nil)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#require_strString (readonly)

Path to require the client of the service

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#serviceString (readonly)

Full name of the service providing the nonstandard LRO functionality

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end

#service_descriptionString (readonly)

The description to place in the comments to this client's attribute in the library services's client class

Returns:

  • (String)


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46

class LroClientPresenter
  attr_reader :service
  attr_reader :client_class_name
  attr_reader :client_class_docname
  attr_reader :client_var_name
  attr_reader :require_str
  attr_reader :service_description
  attr_reader :helper_type

  ##
  # @param service [String]
  #   Full name of the service providing the nonstandard LRO functionality
  # @param client_class_name [String]
  #   Full name of the class of the client of the service
  # @param client_class_docname [String]
  #   Name of the class as it should appear in the documentation
  # @param client_var_name [String]
  #   Name for the variable for the client of the service
  # @param require_str [String]
  #   Path to `require` the client of the service
  # @param service_description [String]
  #   The description to place in the comments to this client's
  #   attribute in the library services's client class
  # @param helper_type [String, nil]
  #   The type of a helper generated for this service if any
  #
  def initialize service:,
                 client_class_name:,
                 client_class_docname:,
                 client_var_name:,
                 require_str:,
                 service_description:,
                 helper_type: nil
    @service = service
    @client_class_name = client_class_name
    @client_class_docname = client_class_docname
    @client_var_name = client_var_name
    @require_str = require_str
    @service_description = service_description
    @helper_type = helper_type
  end
end