Class: Gapic::Presenters::Service::LroClientPresenter
- Inherits:
-
Object
- Object
- Gapic::Presenters::Service::LroClientPresenter
- Defined in:
- lib/gapic/presenters/service/lro_client_presenter.rb
Overview
Presenter for the generation of the client for nonstandard LROs
Instance Attribute Summary collapse
-
#client_class_docname ⇒ String
readonly
Name of the class as it should appear in the documentation.
-
#client_class_name ⇒ String
readonly
Full name of the class of the client of the service.
-
#client_var_name ⇒ String
readonly
Name for the variable for the client of the service.
-
#helper_type ⇒ String. nil
readonly
The type of a helper generated for this service if any.
-
#require_str ⇒ String
readonly
Path to
requirethe client of the service. -
#service ⇒ String
readonly
Full name of the service providing the nonstandard LRO functionality.
-
#service_description ⇒ String
readonly
The description to place in the comments to this client's attribute in the library services's client class.
Instance Method Summary collapse
-
#initialize(service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil) ⇒ LroClientPresenter
constructor
A new instance of LroClientPresenter.
Constructor Details
#initialize(service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil) ⇒ LroClientPresenter
Returns a new instance of LroClientPresenter.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 72 def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end |
Instance Attribute Details
#client_class_docname ⇒ String (readonly)
Name of the class as it should appear in the documentation
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#client_class_name ⇒ String (readonly)
Full name of the class of the client of the service
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#client_var_name ⇒ String (readonly)
Name for the variable for the client of the service
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#helper_type ⇒ String. nil (readonly)
The type of a helper generated for this service if any
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#require_str ⇒ String (readonly)
Path to require the client of the service
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#service ⇒ String (readonly)
Full name of the service providing the nonstandard LRO functionality
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |
#service_description ⇒ String (readonly)
The description to place in the comments to this client's attribute in the library services's client class
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/gapic/presenters/service/lro_client_presenter.rb', line 46 class LroClientPresenter attr_reader :service attr_reader :client_class_name attr_reader :client_class_docname attr_reader :client_var_name attr_reader :require_str attr_reader :service_description attr_reader :helper_type ## # @param service [String] # Full name of the service providing the nonstandard LRO functionality # @param client_class_name [String] # Full name of the class of the client of the service # @param client_class_docname [String] # Name of the class as it should appear in the documentation # @param client_var_name [String] # Name for the variable for the client of the service # @param require_str [String] # Path to `require` the client of the service # @param service_description [String] # The description to place in the comments to this client's # attribute in the library services's client class # @param helper_type [String, nil] # The type of a helper generated for this service if any # def initialize service:, client_class_name:, client_class_docname:, client_var_name:, require_str:, service_description:, helper_type: nil @service = service @client_class_name = client_class_name @client_class_docname = client_class_docname @client_var_name = client_var_name @require_str = require_str @service_description = service_description @helper_type = helper_type end end |